@@ -48,12 +48,14 @@ def printable_value(ast):
 
     raise Exception('Unprintable ast "%s"' % str(ast))
 
-QUOTE  = atom('quote')
-COND   = atom('cond')
-IF     = atom('if')
-DEFINE = atom('define')
-LAMBDA = atom('lambda')
-OR     = atom('or')
-AND    = atom('and')
-TRUE   = bool_(True)
-FALSE  = bool_(False)
+AND       = atom('and')
+COND      = atom('cond')
+DEFINE    = atom('define')
+IF        = atom('if')
+LAMBDA    = atom('lambda')
+LET       = atom('let')
+OR        = atom('or')
+QUOTE     = atom('quote')
+TRUE      = bool_(True)
+FALSE     = bool_(False)
+EMPTYLIST = list_([])
